Møller Auto lietoti auto » Volkswagen Amarok 2.0 106kW meh
Description: Møller Auto piedāvā plašu mazlietotu automobiļu izvēli. Mēs arī garantējam, ka automobilis, kuru Jūs pērkat, ir tādā (tehniskajā) stāvoklī, kādu Jūs to sagaidāt.

EST | LAT | LIT | ENG | RUS

- Par mums
- Lietotas automašīnas
- Kontakti

## Meklēt

Spiediet, lai atvērtu meklēšanu
Spiediet, lai aizvērtu meklēšanu
Cena: all
Jauda: all
Gads: all
Nobraukums: all
Tikai piedāvājumus
Aprīkojums
Adaptīvā pneimatiskā balstiekārta ar elektronisku amortizācijas kontroli
Adaptīva piekares regulēšana (DCC)
Kruīzkontrole
Braukšanas joslu maiņas asistents "Side Assist"
Braukšanas joslu uzturēšanas asistents "Lane Assist"
High beam control "Light Assist"
Atpakaļskata kamera
Vieglmetāla diski
LED priekšējie lukturi, automātiska lukturu augstuma regulēšana
DYNAUDIO skaņas sistēma
Navigācijas sistēma
Mobīlā telefona interfeiss
Ādas apdares sēdekļi
Apsildāms priekšējais vējstikls
Elektriski atverms aizmugurējais vāks
R line interjers
R line eksterjers
Piekabes āķis
Garantija
Meklēt pēc automašīnas reģistrācijas nr. - ievadiet numuru:

# Volkswagen Amarok 2.0 106kW meh

Atpakaļ
Drukāt

Automašīnas ID: | 10235196 / E890213395
Valsts: | Igaunija
Dīleris: | Møller Auto Pärnu
Cena: | 16 490.00 € 0% PVN

Līzinga kalkulators

Pirmā reģistrācija: | 12/2010
Nobraukums: | 133 710 km
Reģistrācijas numurs: | 847KGR
Virsbūves (VIN) numurs: | WV1ZZZ2HZB8024645
Tehniskā skate: | 12/2021
Dzinēja tilpums: | 2000 cm³
Degviela: | dīzelis
Jauda: | 144 ZS (106 kW)
Krāsa: | pelēka
Virsbūves tips: | pikaps
Durvju skaits: | 4/5
Pārnesumkārba: | mehāniskā
Piedziņa: | pilnpiedziņa
"Trade-In" iespēja: | jā

Pārnesumkārba

- Mehāniskā pārnesumkārba

Drošība un aizsardzība

- Stūres pastiprin.
- ABS bremzes
- ESP stabilitātes kontrole
- Trešā bremžu uguns
- Drošības jostas priekšā ar spriegotājiem
- Isofix bērnu sēdeklīšu stiprinājumi
- Centrālā atslēga ar tālvadības pulti
- Imobilaizeris, startēšanas bloķētājs

Asistentu sistēmas

- Kruīzkontrole

Riepas un riteņi

- Vieglmetāla diski
- Ziemas riepas
- Vissezonas riepas

Apgaismojums / lukturi

- Miglas lukturi priekšā
- Miglas lukturi aizmugurē
- Lukturu augstuma regulēšana
- Atsevišķi dienasgaismas lukturi

Multimēdiji

- Radio
- AUX-IN ligzda

Sēdekļi

- Auduma apdares sēdekļi
- Nolokāma aizmugurējo sēdeķļu atzveltne
- Elkoņbalsts priekšā

Interjers / komforts

- Ādas stūre
- Stūres regulēšana
- Ādas ātrumu pārslēdzējs
- Glāžu turētāji
- Elektriski logu pacēlāji priekšā un aizmugurē
- Apsildāms aizmugurējais stikls
- Gumijas paklājiņi
- Elektriski regulējami spoguļi
- Spoguļu apsilde

Apsilde / kondicionēšana

- Automātiska gaisa kondicionēšanas sistēma "Climatronic"

Cits aprīkojums

- Piekabes āķis
- Metāliskā krāsa

### Automašīnu var apskatīt:

Møller Auto Pärnu
Välja 3
Pärnu 80010
Igaunija
E-pasts: parnu@moller.ee
Tālrunis: 447 6100, 447 6142
Apskati kartē
Egon Gribinin
E-pasts: egon.gribinin@moller.ee
Mobīlais tālr.: (+372) 51980170
Genert Karu
E-pasts: genert.karu@moller.ee
Mobīlais tālr.: (+372) 5199 5700
Atpakaļ
Drukāt